// https://www.radix-ui.com/primitives/docs/components/tooltip

import React, { ReactNode } from 'react';
import * as TooltipPrimitive from '@radix-ui/react-tooltip';

export interface BarTooltipProps {
  x: number;
  y: number;
  children: React.ReactNode;
}

export const BarPlotTooltip = ({ x, y, children }: BarTooltipProps) => {
  return (
    <div className="absolute font-sans bg-light border border-secondary text-secondary p-2" style={{ left: `${x}px`, top: `${y}px` }}>
      {children}
    </div>
  );
};

const TooltipProvider = TooltipPrimitive.Provider;
const TooltipTrigger = TooltipPrimitive.Trigger;

export type TooltipProps = {
  children: ReactNode;
  disabled?: boolean;
};

const Tooltip: React.FC<TooltipProps> = ({ disabled, children }) => {
  if (disabled) {
    return null;
  }

  return <TooltipPrimitive.Root>{children}</TooltipPrimitive.Root>;
};

const TooltipContent = React.forwardRef<
  React.ElementRef<typeof TooltipPrimitive.Content>,
  React.ComponentPropsWithoutRef<typeof TooltipPrimitive.Content> & TooltipProps
>(({ className, sideOffset = 4, disabled = false, ...props }, ref) => {
  if (disabled) {
    return null;
  }

  return (
    <TooltipPrimitive.Content
      ref={ref}
      sideOffset={sideOffset}
      className={
        'z-50 overflow-hidden rounded bg-light px-2 py-1 shadow text-xs border border-secondary-200 text-dark animate-in fade-in-0 zoom-in-95 data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=closed]:zoom-out-95 data-[side=bottom]:slide-in-from-top-2 data-[side=left]:slide-in-from-right-2 data-[side=right]:slide-in-from-left-2 data-[side=top]:slide-in-from-bottom-2'
      }
      {...props}
    />
  );
});
TooltipContent.displayName = TooltipPrimitive.Content.displayName;

export { Tooltip, TooltipTrigger, TooltipContent, TooltipProvider };
