import { createSlice, PayloadAction } from '@reduxjs/toolkit';
import type { RootState } from './store';
import { Edge, Node } from './graphQueryResultSlice';

export type HoverStateI = { [id: string]: any };

export type SelectionStateI =
  | {
      selectionType: 'node';
      contentType: 'data';
      content: Node[];
    }
  | {
      // TODO: other selection types
      selectionType: 'relation';
      contentType: 'data';
      content: Edge[];
    };

// Define the initial state using that type
export type InteractionsType = {
  hover?: HoverStateI;
  selection?: SelectionStateI;
};

export const initialState: InteractionsType = {
  hover: undefined,
  selection: undefined,
};

export const interactionSlice = createSlice({
  name: 'interaction',
  // `createSlice` will infer the state type from the `initialState` argument
  initialState,
  reducers: {
    addHover: (state, action: PayloadAction<HoverStateI | undefined>) => {
      state.hover = action.payload;
    },
    unSelect: (state) => {
      state.selection = undefined;
    },
    resultSetSelection: (state, action: PayloadAction<Node[]>) => {
      if (action.payload.length === 0) {
        state.selection = undefined;
      } else {
        state.selection = {
          selectionType: 'node',
          contentType: 'data',
          content: action.payload,
        };
      }
    },
  },
});

export const { addHover, unSelect, resultSetSelection } = interactionSlice.actions;

export const interactionState = (state: RootState) => state.interaction;
export const selectionState = (state: RootState) => state.interaction.selection;

export default interactionSlice.reducer;
