import React from 'react';
import { Button } from '../../../components';
import { VisualizationManagerType } from '../../manager';
import { useSelection, useSessionCache } from '../../../data-access';
import { SelectionConfig } from './SelectionConfig';
import { ActiveVisualizationConfig } from './ActiveVisualizationConfig';

type Props = {
  manager: VisualizationManagerType;
};

export function ConfigPanel({ manager }: Props) {
  const session = useSessionCache();
  const selection = useSelection();

  const buildInfo = import.meta.env.GRAPHPOLARIS_VERSION;

  return (
    <div className="flex flex-col w-full">
      {!!selection && <SelectionConfig selection={selection} />}
      {!selection && manager.activeVisualization && <ActiveVisualizationConfig manager={manager} />}
      {!selection && !manager.activeVisualization && (
        <div>
          {session && session.currentSaveState && (
            <div className="flex flex-col p-4 border-b">
              <span className="text-sm font-bold">Connection details</span>
              <span className="text-xs font-semibold">Name</span>
              <span className="text-xs">{session.saveStates[session.currentSaveState].name}</span>
              <span className="text-xs font-semibold">Database</span>
              <span className="text-xs">{session.saveStates[session.currentSaveState].db.internalDatabaseName}</span>
              <span className="text-xs font-semibold">Protocol</span>
              <span className="text-xs">{session.saveStates[session.currentSaveState].db.protocol}</span>
              <span className="text-xs font-semibold">Hostname</span>
              <span className="text-xs">{session.saveStates[session.currentSaveState].db.url}</span>
              <span className="text-xs font-semibold">Port</span>
              <span className="text-xs">{session.saveStates[session.currentSaveState].db.port}</span>
            </div>
          )}
        </div>
      )}

      {buildInfo === 'dev' && (
        <div className="mt-auto p-2 bg-light">
          <Button
            type="primary"
            variant="outline"
            size="xs"
            label="Report an issue"
            onClick={() =>
              window.open(
                'https://app.asana.com/-/login?u=https%3A%2F%2Fform.asana.com%2F%3Fk%3D2QEC88Dl7ETs2wYYWjkMXg%26d%3D1206648675960041&error=01',
                '_blank',
              )
            }
            additionalClasses="block w-full"
          />
        </div>
      )}
    </div>
  );
}
